# This file is part of Indico.
# Copyright (C) 2002 - 2018 European Organization for Nuclear Research (CERN).
#
# Indico is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 3 of the
# License, or (at your option) any later version.
#
# Indico is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Indico; if not, see <http://www.gnu.org/licenses/>.


from indico_payment_docdata import _
from indico_payment_docdata.blueprint import blueprint
from wtforms.fields import URLField
from wtforms.validators import DataRequired

from indico.core.plugins import IndicoPlugin, url_for_plugin
from indico.modules.events.payment import (PaymentEventSettingsFormBase, PaymentPluginMixin,
                                           PaymentPluginSettingsFormBase)
from indico.util.string import remove_accents, str_to_ascii


class PluginSettingsForm(PaymentPluginSettingsFormBase):
    url = URLField(_('API URL'), [DataRequired()], description=_('URL of the DocData script.'))
    # b usiness = StringField(_('Business'), [Optional(), validate_business],
    #                       description=_('The default DocData ID or email address associated with a DocData account. '
    #                                     'Event managers will be able to override this.'))
    buisness = ''


class EventSettingsForm(PaymentEventSettingsFormBase):
    # business = StringField(_('Business'), [UsedIf(lambda form, _: form.enabled.data), DataRequired(),
    #                                       validate_business],
    #                       description=_('The DocData ID or email address associated with a DocData account.'))
    business = ''


class DocdataPaymentPlugin(PaymentPluginMixin, IndicoPlugin):
    """Credit Card

    Provides a payment method using the DocData IPN API.
    """
    configurable = True
    settings_form = PluginSettingsForm
    event_settings_form = EventSettingsForm
    default_settings = {'method_name': 'Credit Card',
                        'url': 'https://example.com',
                        'business': ''}
    default_event_settings = {'enabled': False,
                              'method_name': None,
                              'business': None}

    @property
    def logo_url(self):
        return url_for_plugin(self.name + '.static', filename='images/logo.png')

    def get_blueprints(self):
        return blueprint

    def adjust_payment_form_data(self, data):
        event = data['event']
        registration = data['registration']
        data['item_name'] = '{}: registration for {}'.format(
            str_to_ascii(remove_accents(registration.full_name)),
            str_to_ascii(remove_accents(event.title))
        )
        data['start_url'] = url_for_plugin('payment_docdata.start', registration.locator.uuid, _external=True)
        data['return_url'] = url_for_plugin('payment_docdata.success', registration.locator.uuid, _external=True)
        data['cancel_url'] = url_for_plugin('payment_docdata.cancel', registration.locator.uuid, _external=True)
        data['notify_url'] = url_for_plugin('payment_docdata.notify', registration.locator.uuid, _external=True)
